API docs for “spamfighter.interfaces.ITaggedMessage”

# Class s.i.ITaggedMessage(IMessage):

Part of spamfighter.interfaces View Source View In Hierarchy

Сообщение с прицепленными к нему тэгами.

Method | addTag | Добавить тэг tag к сообщению.
Method | getTags | Получить все текущие тэги сообщения.
Method | checkHasAllTags | Проверить, содержит ли сообщение все указанные тэги.
Method | checkHasNoTags | Проверить, что в сообщении нет ни одного из указанных тэгов.

Inherited from IMessage:

Method | get | Получить атрибут по имени.

def addTag(tag): (source)
Добавить тэг tag к сообщению.

Parameters | tag | тэг (type: `str` )

def getTags(): (source)
Получить все текущие тэги сообщения.

Returns | список тэгов (type: `list(str)` )

def checkHasAllTags(tags): (source)
Проверить, содержит ли сообщение все указанные тэги.

Parameters | tags | список тэгов (type: `list(str)` )
Returns | содержит ли все указанные тэги? (type: `bool` )

def checkHasNoTags(tags): (source)
Проверить, что в сообщении нет ни одного из указанных тэгов.

Parameters | tags | список тэгов (type: `list(str)` )
Returns | не содержит ли все указанные тэги? (type: `bool` )